pub struct WindSample {
pub velocity: [f32; 3],
pub pressure: f32,
}Expand description
A single wind measurement at a point in space and time.
Fields
velocity: [f32; 3]World-space wind velocity at this point and time (m/s).
pressure: f32Dynamic pressure = 0.5 * rho * v², where rho = 1.225 kg/m³.